pub struct VectorSearchPlugin;Expand description
Plugin that builds the <site>/search/ vector bundle.
Examples
use ssg::plugin::Plugin;
use ssg::search_index::VectorSearchPlugin;
assert_eq!(VectorSearchPlugin.name(), "vector-search");Trait Implementations
Sourceimpl Clone for VectorSearchPlugin
impl Clone for VectorSearchPlugin
Sourcefn clone(&self) -> VectorSearchPlugin
fn clone(&self) -> VectorSearchPlugin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VectorSearchPlugin
Sourceimpl Debug for VectorSearchPlugin
impl Debug for VectorSearchPlugin
Sourceimpl Default for VectorSearchPlugin
impl Default for VectorSearchPlugin
Sourcefn default() -> VectorSearchPlugin
fn default() -> VectorSearchPlugin
Returns the “default value” for a type. Read more
Sourceimpl Plugin for VectorSearchPlugin
impl Plugin for VectorSearchPlugin
Sourcefn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
fn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
Called after site compilation completes. Read more
Sourcefn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
fn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
Called before site compilation begins. Read more
Sourcefn transform_html(
&self,
html: &str,
_path: &Path,
_ctx: &PluginContext,
) -> Result<String, SsgError>
fn transform_html( &self, html: &str, _path: &Path, _ctx: &PluginContext, ) -> Result<String, SsgError>
Per-file HTML transform hook — called once per HTML file during
the fused transform pass. Read more
Sourcefn has_transform(&self) -> bool
fn has_transform(&self) -> bool
Returns
true if this plugin implements transform_html.
Override to true to opt in to the fused transform pass.Sourcefn needs_all_files(&self) -> bool
fn needs_all_files(&self) -> bool
Returns
true if this plugin must always observe the full
cache.html_files() list — even during --incremental
rebuilds that only invalidated a handful of pages. Read moreAuto Trait Implementations
impl Freeze for VectorSearchPlugin
impl RefUnwindSafe for VectorSearchPlugin
impl Send for VectorSearchPlugin
impl Sync for VectorSearchPlugin
impl Unpin for VectorSearchPlugin
impl UnsafeUnpin for VectorSearchPlugin
impl UnwindSafe for VectorSearchPlugin